==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/LOOKUPQUERY_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour LOOKUPQUERY_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LOOKUPQUERY_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOOKUPQUERYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOOKUPQUERYTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LOOKUPQUERY_Type", propOrder = {
    "lookupquerycode",
    "lookupquerytext"
})
public class LOOKUPQUERY_Type {

    @XmlElement(name = "LOOKUPQUERYCODE", required = true)
    protected String lookupquerycode;
    @XmlElement(name = "LOOKUPQUERYTEXT")
    protected String lookupquerytext;

    /**
     * Obtient la valeur de la propriété lookupquerycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOOKUPQUERYCODE() {
        return lookupquerycode;
    }

    /**
     * Définit la valeur de la propriété lookupquerycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOOKUPQUERYCODE(String value) {
        this.lookupquerycode = value;
    }

    /**
     * Obtient la valeur de la propriété lookupquerytext.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOOKUPQUERYTEXT() {
        return lookupquerytext;
    }

    /**
     * Définit la valeur de la propriété lookupquerytext.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOOKUPQUERYTEXT(String value) {
        this.lookupquerytext = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/LOOKUPQUERY_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LOOKUPQUERY_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LOOKUPQUERY_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOOKUPQUERYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOOKUPQUERYTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LOOKUPQUERY_Type", propOrder = {
    "lookupquerycode",
    "lookupquerytext"
})
public class LOOKUPQUERY_Type {

    @XmlElement(name = "LOOKUPQUERYCODE", required = true)
    protected String lookupquerycode;
    @XmlElement(name = "LOOKUPQUERYTEXT")
    protected String lookupquerytext;

    /**
     * Gets the value of the lookupquerycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOOKUPQUERYCODE() {
        return lookupquerycode;
    }

    /**
     * Sets the value of the lookupquerycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOOKUPQUERYCODE(String value) {
        this.lookupquerycode = value;
    }

    /**
     * Gets the value of the lookupquerytext property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOOKUPQUERYTEXT() {
        return lookupquerytext;
    }

    /**
     * Sets the value of the lookupquerytext property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOOKUPQUERYTEXT(String value) {
        this.lookupquerytext = value;
    }

}
